@@ -30,9 +30,8 @@ async def stop(hub):
     """
     Stop the event bus
     """
-    if hub.evbus.BUS is not None:
-        hub.log.debug("Stopping the event bus")
-        await hub.evbus.BUS.put(STOP_ITERATION)
+    hub.log.debug("Stopping the event bus")
+    hub.evbus.BUS.put_nowait(STOP_ITERATION)
 
     hub.evbus.RUN_FOREVER = False
 
